#include <avr/pgmspace.h>
#include "font.h"
extern unsigned char font6_8[92][6];

int Column_Pin0 = 5;
int Column_Pin1 = 6;
int Column_Pin2 = 7;
int Row_Pin0 = 2;
int Row_Pin1 = 3;
int Row_Pin2 = 4;

int LCD5110_SCK_PIN = 13;
int LCD5110_MI_PIN = 11;
int LCD5110_DC_PIN = 10;
int LCD5110_RST_PIN = 8;
int LCD5110_CS_PIN = 9;

//Define the LCD Operation function
void LCD5110_LCD_write_byte(unsigned char dat,unsigned char IBridge_LCD5110_Mode);


//Define the hardware operation function
void GPIO_Config(void);
void LCD5110_SCK(unsigned char temp);
void LCD5110_MI(unsigned char temp);
void LCD5110_CS(unsigned char temp);
void LCD5110_RST(unsigned char temp);
void LCD5110_DC(unsigned char temp);

void Iinit()
{
	GPIO_Config();

	LCD5110_DC(1);//LCD_DC = 1;
	LCD5110_MI(1);//SPI_MO = 1;
	LCD5110_SCK(1);//SPI_SCK = 1;
	LCD5110_CS(1);//SPI_CS = 1;
	
	LCD5110_RST(0);//LCD_RST = 0;
	delay(10);
	LCD5110_RST(1);//LCD_RST = 1;

	LCD5110_LCD_write_byte(0x21,0);
	LCD5110_LCD_write_byte(0xc6,0);
	LCD5110_LCD_write_byte(0x06,0);
	LCD5110_LCD_write_byte(0x13,0);
	LCD5110_LCD_write_byte(0x20,0);
	LCD5110_clear();
	LCD5110_LCD_write_byte(0x0c,0);
}

void LCD5110_LCD_write_byte(unsigned char dat,unsigned char mode)
{
	unsigned char i;

	LCD5110_CS(0);//SPI_CS = 0;

	if (0 == mode)
		LCD5110_DC(0);//LCD_DC = 0;
	else
		LCD5110_DC(1);//LCD_DC = 1;

	for(i=0;i<8;i++)
	{
		LCD5110_MI(dat & 0x80);//SPI_MO = dat & 0x80;
		dat = dat<<1;
		LCD5110_SCK(0);//SPI_SCK = 0;
		LCD5110_SCK(1);//SPI_SCK = 1;
	}

	LCD5110_CS(1);//SPI_CS = 1;

}

void LCD5110_write_char(unsigned char c)
{
	unsigned char line;
	unsigned char ch = 0;

	c = c - 32;

	for(line=0;line<6;line++)
	{
		ch = pgm_read_byte(&(font6_8[c][line]));
		LCD5110_LCD_write_byte(ch,1);
		
	}
}
void LCD5110_write_char_reg(unsigned char c)
{
	unsigned char line;
	unsigned char ch = 0;

	c = c - 32;

	for(line=0;line<6;line++)
	{
		ch = ~(pgm_read_byte(&(font6_8[c][line])));
		LCD5110_LCD_write_byte(ch,1);
		
	}
}

void LCD5110_write_string(char *s)
{
	unsigned char ch;
  	while(*s!='\0')
	{
		ch = *s;
		LCD5110_write_char(ch);
		s++;
	}
}


void LCD5110_clear()
{
	unsigned char i,j;
	for(i=0;i<6;i++)
		for(j=0;j<84;j++)
			LCD5110_LCD_write_byte(0,1);
}

void LCD5110_set_XY(unsigned char X,unsigned char Y)
{
	unsigned char x;
	x = 6*X;
	//y = 8*Y;

	LCD5110_LCD_write_byte(0x40|Y,0);
	LCD5110_LCD_write_byte(0x80|x,0);
}

void LCD5110_Write_Dec(unsigned int b)
{
	unsigned char datas[3];

	datas[0] = b/1000;
	b = b - datas[0]*1000;
	datas[1] = b/100;
	b = b - datas[1]*100;
	datas[2] = b/10;
	b = b - datas[2]*10;
	datas[3] = b;

	datas[0]+=48;
	datas[1]+=48;
	datas[2]+=48;
	datas[3]+=48;

	LCD5110_write_char(datas[0]);
	LCD5110_write_char(datas[1]);
	LCD5110_write_char(datas[2]);
	LCD5110_write_char(datas[3]);

	
}

void GPIO_Config()
{
  pinMode(LCD5110_SCK_PIN, OUTPUT);
  pinMode(LCD5110_MI_PIN, OUTPUT);
  pinMode(LCD5110_DC_PIN, OUTPUT);
  pinMode(LCD5110_RST_PIN, OUTPUT);
  pinMode(LCD5110_CS_PIN, OUTPUT);
  
  pinMode(Column_Pin0, OUTPUT);
  pinMode(Column_Pin1, OUTPUT);
  pinMode(Column_Pin2, OUTPUT);
  //pinMode(IBridge_Column_Pin3, OUTPUT);

  pinMode(Row_Pin0, INPUT);
  pinMode(Row_Pin1, INPUT);
  pinMode(Row_Pin2, INPUT);
 // pinMode(IBridge_Row_Pin3, INPUT);
}

void LCD5110_CS(unsigned char temp)
{
	if (temp) digitalWrite(LCD5110_CS_PIN, HIGH);
	else digitalWrite(LCD5110_CS_PIN, LOW);
}

void LCD5110_RST(unsigned char temp)
{
	if (temp) digitalWrite(LCD5110_RST_PIN, HIGH);
	else digitalWrite(LCD5110_RST_PIN, LOW);
}

void LCD5110_DC(unsigned char temp)
{
	if (temp) digitalWrite(LCD5110_DC_PIN, HIGH);
	else digitalWrite(LCD5110_DC_PIN, LOW);
}

void LCD5110_MI(unsigned char temp)
{
	if (temp) digitalWrite(LCD5110_MI_PIN, HIGH);
	else digitalWrite(LCD5110_MI_PIN, LOW);
}

void LCD5110_SCK(unsigned char temp)
{
	if (temp) digitalWrite(LCD5110_SCK_PIN, HIGH);
	else digitalWrite(LCD5110_SCK_PIN, LOW);
}

unsigned char Read_Key()
{
  //unsigned char i = 10;

  //Column 0 scan
  
  digitalWrite(Column_Pin0, HIGH);
  digitalWrite(Column_Pin1, LOW);
  digitalWrite(Column_Pin2, LOW);

  if((digitalRead(Row_Pin0)) &&  !(digitalRead(Row_Pin1)) && !(digitalRead(Row_Pin2)))
    {
     delay(100);                                                                                                             
    while((digitalRead(Row_Pin0)) &&  !(digitalRead(Row_Pin1)) && !(digitalRead(Row_Pin2)));
    return (1);
    }
  if(!(digitalRead(Row_Pin0)) && (digitalRead(Row_Pin1)) &&  !(digitalRead(Row_Pin2)))
     {
     delay(100);                                                                                                             
    while(!(digitalRead(Row_Pin0)) && (digitalRead(Row_Pin1)) &&  !(digitalRead(Row_Pin2)));
    return (2);
    }
  if(!(digitalRead(Row_Pin0)) && !(digitalRead(Row_Pin1)) &&   (digitalRead(Row_Pin2)))
     {
     delay(100);                                                                                                             
    while(!(digitalRead(Row_Pin0)) && !(digitalRead(Row_Pin1)) &&   (digitalRead(Row_Pin2)));
    return (3);
    }
    
  digitalWrite(Column_Pin0, LOW);
  digitalWrite(Column_Pin1, HIGH);
  digitalWrite(Column_Pin2, LOW);

  if((digitalRead(Row_Pin0)) &&  !(digitalRead(Row_Pin1)) && !(digitalRead(Row_Pin2)))
    {
     delay(100);                                                                                                             
    while((digitalRead(Row_Pin0)) &&  !(digitalRead(Row_Pin1)) && !(digitalRead(Row_Pin2)));
    return (4);
    }
  if(!(digitalRead(Row_Pin0)) && (digitalRead(Row_Pin1)) &&  !(digitalRead(Row_Pin2)))
    {
     delay(100);                                                                                                             
    while(!(digitalRead(Row_Pin0)) && (digitalRead(Row_Pin1)) &&  !(digitalRead(Row_Pin2)));
    return (5);
    }
  if(!(digitalRead(Row_Pin0)) && !(digitalRead(Row_Pin1)) &&   (digitalRead(Row_Pin2)))
     {
     delay(100);                                                                                                             
    while(!(digitalRead(Row_Pin0)) && !(digitalRead(Row_Pin1)) &&   (digitalRead(Row_Pin2)));
    return (6);
    }
    
  digitalWrite(Column_Pin0, LOW);
  digitalWrite(Column_Pin1, LOW);
  digitalWrite(Column_Pin2, HIGH);

  if((digitalRead(Row_Pin0)) &&  !(digitalRead(Row_Pin1)) && !(digitalRead(Row_Pin2)))
    {
     delay(100);                                                                                                             
    while((digitalRead(Row_Pin0)) &&  !(digitalRead(Row_Pin1)) && !(digitalRead(Row_Pin2)));
    return (7);
    }
  if(!(digitalRead(Row_Pin0)) && (digitalRead(Row_Pin1)) &&  !(digitalRead(Row_Pin2)))
    {
     delay(100);                                                                                                             
    while(!(digitalRead(Row_Pin0)) && (digitalRead(Row_Pin1)) &&  !(digitalRead(Row_Pin2)));
    return (8);
    }
  if(!(digitalRead(Row_Pin0)) && !(digitalRead(Row_Pin1)) &&   (digitalRead(Row_Pin2)))
        {
     delay(100);                                                                                                             
    while(!(digitalRead(Row_Pin0)) && !(digitalRead(Row_Pin1)) &&   (digitalRead(Row_Pin2)));
    return (9);
    } 
    
    
    
     return (0);

}

void setup()
{
 Iinit();
  
  LCD5110_write_string("ElecFreaks");
  delay(1000);
  LCD5110_clear();
  Serial.begin(9600); 
}

void loop()
{
  unsigned char temp = 0;
  while(1)
  {
    temp = Read_Key();
    
		switch (temp)
		{
			case 1:
				LCD5110_write_char('0');
                                Serial.println("0");
				break;
			case 2:
				LCD5110_write_char('1');
                                Serial.println("1");
				break;
			case 3:
				LCD5110_write_char('2');
                                Serial.println("2");
				break;
			case 4:
				LCD5110_write_char('3');
                                Serial.println("3");
				break;
			case 5:
				LCD5110_write_char('4');
                                Serial.println("4");
				break;
			case 6:
				LCD5110_write_char('5');
                                Serial.println("5");
				break;
			case 7:
				LCD5110_write_char('6');
                                Serial.println("6");
				break;
			case 8:
				LCD5110_write_char('7');
                                Serial.println("7");
				break;
			case 9:
				LCD5110_write_char('8');
                                Serial.                                                                      println("8");  
				break;
			
			

			default:
				break;
		}
      temp = 0;
  }
}

